summaryrefslogtreecommitdiffstats
path: root/dom/security/nsHTTPSOnlyUtils.h
diff options
context:
space:
mode:
Diffstat (limited to 'dom/security/nsHTTPSOnlyUtils.h')
-rw-r--r--dom/security/nsHTTPSOnlyUtils.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/dom/security/nsHTTPSOnlyUtils.h b/dom/security/nsHTTPSOnlyUtils.h
index 73a5219082..7e36bfadbd 100644
--- a/dom/security/nsHTTPSOnlyUtils.h
+++ b/dom/security/nsHTTPSOnlyUtils.h
@@ -95,12 +95,13 @@ class nsHTTPSOnlyUtils {
/**
* Determines if the request was previously upgraded with HTTPS-First, creates
* a downgraded URI and logs to console.
* @param aStatus Status code
* @param aChannel Failed channel
* @return URI with http-scheme or nullptr
*/
static already_AddRefed<nsIURI> PotentiallyDowngradeHttpsFirstRequest(
- nsIChannel* aChannel, nsresult aStatus);
+ mozilla::net::DocumentLoadListener* aDocumentLoadListener,
+ nsresult aStatus);
/**
* Checks if the error code is on a block-list of codes that are probably
@@ -95,12 +95,13 @@ class nsHTTPSOnlyUtils {
* Determines if the request was previously upgraded with HTTPS-First, creates
* a downgraded URI and logs to console.
- * @param aStatus Status code
- * @param aChannel Failed channel
- * @return URI with http-scheme or nullptr
+ * @param aStatus Status code
+ * @param aDocumentLoadListener Failed document load listener
+ * @return URI with http-scheme or nullptr
*/
static already_AddRefed<nsIURI> PotentiallyDowngradeHttpsFirstRequest(